import { useAjax } from "@/Hook/useAjax"
import { CheckOutlined, QuestionCircleOutlined, SyncOutlined } from "@ant-design/icons"
import { Button, message, Modal, Space, Table, Tooltip } from "antd"
import React, { useEffect, useState } from "react"
import style from '../GoodsModal/index.less'
import columns from './tableConfig'
import { getDataSourceV3Api, sysDataSourceV3Api } from "@/services/adqV3/global"

/**
 * 获取数据源
 * @returns 
 */
interface Props {
    promotedObjectType?: string
    visible?: boolean,
    onClose?: () => void,
    onChange?: (data: PULLIN.AccountCreateLogsProps[]) => void,
    data: PULLIN.AccountCreateLogsProps[]
}
const DataSourceModal: React.FC<Props> = (props) => {

    /************************/
    const { visible, onClose, data: data1, onChange, promotedObjectType } = props
    const [tableData, setTableData] = useState<any[]>([])//table数据
    const [selectAdz, setSelectAdz] = useState<number>(1)   // 选择广告主
    const [data, setData] = useState<PULLIN.AccountCreateLogsProps[]>(data1)

    const getDataSource = useAjax((params) => getDataSourceV3Api(params))
    const sysDataSource = useAjax((params) => sysDataSourceV3Api(params))
    /************************/

    useEffect(() => {
        if (data?.length > 0) {
            getList([data[selectAdz - 1].accountId])
        } else {
            setTableData([])
        }
    }, [selectAdz])

    // 获取数据源
    const getList = (params: number[]) => {
        getDataSource.run({ accountIds: params, promotedObjectType }).then(res => {
            if (res && Object.keys(res)?.indexOf(params[0].toString()) !== -1) {
                setTableData(res[params[0]])
            } else {
                setTableData([])
            }
        })
    }

    const handleOk = () => {
        onChange && onChange(data)
    }

    // 同步数据源
    const synDataSourceList = () => {
        sysDataSource.run(data?.map(item => item?.accountId)).then(res => {
            getList([data[selectAdz - 1].accountId])
        })
    }

    /** 设置选中广告主 */
    const handleSelectAdz = (value: number, item: any) => {
        if (value === selectAdz) {
            return
        }
        setSelectAdz(value)
    }

    /** 表格选折 */
    const onChangeTable = (_: React.Key[], selectedRows: any) => {
        let newData = JSON.parse(JSON.stringify(data))
        newData[selectAdz - 1]['userActionSetsList'] = selectedRows
        setData([...newData])
    }

    /** 一键设置 */
    const setOnekey = () => {
        let dataSourceIds: number[] = data[selectAdz - 1]['userActionSetsList']?.map((item: { userActionSetId: number }) => item.userActionSetId) as number[]
        let newData: PULLIN.AccountCreateLogsProps[] = JSON.parse(JSON.stringify(data))
        const hide = message.loading(`正在设置...`, 0, () => {
            message.success('设置成功');
        });
        getDataSource.run({ accountIds: newData?.filter(item => item.accountId !== data[selectAdz - 1].accountId)?.map(item => item?.accountId), promotedObjectType }).then(res => {
            if (res && typeof res === 'object') {
                Object.keys(res).forEach((key: string) => {
                    let values = dataSourceIds.map(id => {
                        let value = res[key]?.find((item: { userActionSetId: number }) => item.userActionSetId === id)
                        if (value) {
                            return { ...value, id: value.userActionSetId }
                        }
                        return undefined
                    }).filter(item => item)
                    if (values.length > 0) {
                        newData = newData.map(item => {
                            if (item.accountId.toString() === key.toString()) {
                                return { ...item, userActionSetsList: values }
                            }
                            return item
                        })
                    }
                })
                setData(newData)
            }
            message.success('设置完成');
            hide()
        })
    }

    // 清空已选
    const clearUserActionSets = () => {
        let newData = JSON.parse(JSON.stringify(data))
        newData[selectAdz - 1]['userActionSetsList'] = []
        setData([...newData])
    }

    return <Modal
        title={<Space>
            <span>数据源</span>
            <Button size="small" onClick={() => { synDataSourceList() }} type='link' loading={sysDataSource?.loading}>同步数据源</Button>
        </Space>}
        open={visible}
        onCancel={() => { onClose && onClose() }}
        onOk={handleOk}
        width={900}
        className={`${style.SelectPackage} modalResetCss`}
        bodyStyle={{ padding: '0 10px 0 10px' }}
    >
        <div className={style.content}>
            <div className={style.left}>
                <h4 className={style.title}>媒体账户</h4>
                <div className={style.accountIdList}>
                    {data?.map((item, index) => {
                        let userActionSetsList = data?.[index]?.userActionSetsList || []
                        return <div key={index} onClick={() => { handleSelectAdz(index + 1, item) }} className={`${style.accItem} ${selectAdz === index + 1 && style.select} `}>
                            {item?.accountId}
                            {userActionSetsList?.length > 0 && <CheckOutlined style={{ color: '#1890ff' }} />}
                        </div>
                    })}
                </div>
            </div>
            <div className={style.right}>
                <Space style={{ marginBottom: 10 }} align="end" size={0}>
                    <Button icon={<SyncOutlined />} type='link' loading={getDataSource?.loading} onClick={() => { getList([data[selectAdz - 1].accountId]) }}>刷新</Button>
                    {data.length > 1 && <Button disabled={!data[selectAdz - 1]['userActionSetsList']?.length} onClick={setOnekey} type="link" loading={getDataSource.loading}>
                        <Space>
                            <span>一键设置</span>
                            <Tooltip color="#FFF" overlayInnerStyle={{ color: '#000' }} title="设置其它账号有相同ID的数据源为那个账号的数据源（注意需要数据源ID相同，否则不设置）">
                                <QuestionCircleOutlined />
                            </Tooltip>
                        </Space>
                    </Button>}
                    {(data[selectAdz - 1]?.userActionSetsList || [])?.length > 0 && <Button type='link' onClick={() => clearUserActionSets()}>清空</Button>}
                </Space>
                <Table
                    columns={columns() as any}
                    dataSource={tableData}
                    size="small"
                    loading={getDataSource?.loading}
                    scroll={{ y: 400 }}
                    bordered
                    rowKey={'userActionSetId'}
                    rowSelection={{
                        type: 'checkbox',
                        selectedRowKeys: data[selectAdz - 1]?.userActionSetsList?.map((item: any) => item?.userActionSetId),
                        onChange: onChangeTable
                    }}
                />
            </div>
        </div>
    </Modal>
}

export default React.memo(DataSourceModal)