/** 创意组件化详情 */
export const dynamicRules = {
	"jump_info": {
		"name": "jump_info",
		"elementType": "LANDING_PAGE_STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "落地页组件",
		"parentName": "",
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 3
		},
		"path": "/jump_info",
		"children": {
			"page_type": {
				"name": "page_type",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": true,
				"description": "落地页类型",
				"parentName": "jump_info",
				"enumProperty": {
					"enumeration": [{
						"value": "PAGE_TYPE_H5",
						"description": "自定义落地页"
					}, {
						"value": "PAGE_TYPE_XJ_WEB_H5",
						"description": "蹊径网页落地页"
					}, {
						"value": "PAGE_TYPE_WECHAT_MINI_PROGRAM",
						"description": "微信小程序"
					}, {
						"value": "PAGE_TYPE_WECHAT_CANVAS",
						"description": "原生推广页"
					}, {
						"value": "PAGE_TYPE_XJ_QUICK",
						"description": "蹊径性能版落地页"
					}, {
						"value": "PAGE_TYPE_APP_DEEP_LINK",
						"description": "应用直达"
					}]
				},
				"path": "/jump_info/page_type"
			},
			"page_spec": {
				"name": "page_spec",
				"elementType": "STRUCT",
				"fieldType": "STRUCT",
				"required": false,
				"description": "落地页数据(详见接口文档)",
				"parentName": "jump_info",
				"path": "/jump_info/page_spec"
			},
			"backups": {
				"name": "backups",
				"elementType": "LANDING_PAGE_STRUCT",
				"fieldType": "STRUCT_ARRAY",
				"required": false,
				"description": "兜底落地页(详见接口文档)",
				"parentName": "jump_info",
				"path": "/jump_info/backups"
			}
		}
	},
	"brand": {
		"name": "brand",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "品牌形象",
		"parentName": "",
		"enumProperty": {
			"default": ""
		},
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 1
		},
		"structProperty": {},
		"restriction": {},
		"children": {
			"brand_image_id": {
				"name": "brand_image_id",
				"elementType": "IMAGE",
				"fieldType": "STRING",
				"required": true,
				"description": "品牌标识图",
				"parentName": "brand",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"imageRestriction": {
						"width": 512,
						"height": 512,
						"fileSize": 400,
						"fileFormat": ["IMAGE_TYPE_JPG", "IMAGE_TYPE_PNG"]
					}
				}
			},
			"brand_name": {
				"name": "brand_name",
				"elementType": "TEXT",
				"fieldType": "STRING",
				"required": true,
				"description": "品牌名称",
				"parentName": "brand",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"textRestriction": {
						"minLength": 2,
						"maxLength": 12,
						"textPattern": "^[-+·.！：・（）‘’()&!:'\\s\\w\\u4e00-\\u9fff]+$"
					}
				}
			},
			"jump_info": {
				"name": "jump_info",
				"elementType": "LANDING_PAGE_STRUCT",
				"fieldType": "STRUCT",
				"required": false,
				"description": "品牌形象跳转",
				"parentName": "brand",
				"path": "/brand/jump_info"
			},
			"page_type": {
				"name": "page_type",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": true,
				"description": "落地页类型",
				"parentName": "jump_info",
				"enumProperty": {
					"enumeration": [{
						"value": "PAGE_TYPE_WECHAT_CHANNELS_PROFILE",
						"description": "视频号"
					}, {
						"value": "PAGE_TYPE_H5_PROFILE",
						"description": "品牌简介页"
					}, {
						"value": "PAGE_TYPE_SEARCH_BRAND_AREA",
						"description": "搜一搜超级品专"
					}, {
						"value": "PAGE_TYPE_WECHAT_OFFICIAL_ACCOUNT_DETAIL",
						"description": "公众号"
					}, {
						"value": "PAGE_TYPE_NOT_USED",
						"description": "自定义"
					}]
				},
				"path": "/brand/jump_info/page_type"
			},
			"page_spec": {
				"name": "page_spec",
				"elementType": "STRUCT",
				"fieldType": "STRUCT",
				"required": false,
				"description": "落地页数据(详见接口文档)",
				"parentName": "jump_info",
				"path": "/brand/jump_info/page_spec"
			}
		}
	},
	"action_button": {
		"name": "action_button",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "行动按钮组件",
		"enumProperty": {},
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 1
		},
		"structProperty": {},
		"restriction": {},
		"children": {
			"button_text": {
				"name": "button_text",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": true,
				"description": "按钮文字，当前仅支持“了解更多”,“去逛逛”,“查看详情”,“立即体验”,“立即咨询”,“立即开通”,“立即抢购”,“立即申请”,“立即秒杀”,“立即购买”,“立即预定”,“立即预约”,“立即领取”,“观看直播”,“进入小程序”,“领取优惠”",
				"parentName": "action_button",
				"enumProperty": {
					"enumeration": [{
						"value": "了解更多",
						"description": "",
						"category": ""
					}, {
						"value": "去逛逛",
						"description": "",
						"category": ""
					}, {
						"value": "查看详情",
						"description": "",
						"category": ""
					}, {
						"value": "立即体验",
						"description": "",
						"category": ""
					}, {
						"value": "立即咨询",
						"description": "",
						"category": ""
					}, {
						"value": "立即开通",
						"description": "",
						"category": ""
					}, {
						"value": "立即抢购",
						"description": "",
						"category": ""
					}, {
						"value": "立即申请",
						"description": "",
						"category": ""
					}, {
						"value": "立即秒杀",
						"description": "",
						"category": ""
					}, {
						"value": "立即购买",
						"description": "",
						"category": ""
					}, {
						"value": "立即预定",
						"description": "",
						"category": ""
					}, {
						"value": "立即预约",
						"description": "",
						"category": ""
					}, {
						"value": "立即领取",
						"description": "",
						"category": ""
					}, {
						"value": "观看直播",
						"description": "",
						"category": ""
					}, {
						"value": "进入小程序",
						"description": "",
						"category": ""
					}, {
						"value": "领取优惠",
						"description": "",
						"category": ""
					}],
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {}
			}
		}
	},
	"description": {
		"name": "description",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "描述组件",
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 1
		},
		"children": {
			"content": {
				"name": "content",
				"elementType": "TEXT",
				"fieldType": "STRING",
				"required": true,
				"description": "文案（1-30字）",
				"parentName": "description",
				"restriction": {
					"textRestriction": {
						"minLength": 1,
						"maxLength": 30,
						"textPattern": "^[^\\<\\>\\&'\\\"\\x08\\x09\\x0A\\x0D\\\\]+$"
					}
				}
			}
		}
	},
	"text_link": {
		"name": "text_link",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": false,
		"description": "文字链组件",
		"parentName": "",
		"arrayProperty": {
			"minNumber": 0,
			"maxNumber": 1
		},
		"children": {
			"link_name_type": {
				"name": "link_name_type",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": true,
				"description": "文字链文案",
				"parentName": "text_link",
				"enumProperty": {
					"enumeration": [{
						"value": "MORE_INFO",
						"description": "了解更多"
					}, {
						"value": "BUY_NOW",
						"description": "立即购买"
					}, {
						"value": "RESERVATION_BUY",
						"description": "预约购买"
					}, {
						"value": "CONSULT_NOW",
						"description": "立即咨询"
					}, {
						"value": "GO_SHOPPING",
						"description": "去逛逛"
					}, {
						"value": "BOOK_DRIVE",
						"description": "预约试驾"
					}, {
						"value": "GET_COUPONS",
						"description": "领取优惠"
					}, {
						"value": "RESERVE_NOW",
						"description": "立即预约"
					}, {
						"value": "MAKE_AN_APPOINTMENT",
						"description": "预约活动"
					}, {
						"value": "WATCH_LIVE",
						"description": "观看直播"
					}, {
						"value": "BOOK_NOW",
						"description": "立即预定"
					}, {
						"value": "APPLY_NOW",
						"description": "立即申请"
					}, {
						"value": "ENTER_MINI_PROGRAM",
						"description": "进入小程序"
					}]
				}
			},
			"jump_info": {
				"name": "jump_info",
				"elementType": "LANDING_PAGE_STRUCT",
				"fieldType": "STRUCT",
				"required": true,
				"description": "文字链落地页",
				"parentName": "text_link",
				"path": "/text_link/jump_info"
			},
			"page_type": {
				"name": "page_type",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": true,
				"description": "落地页类型",
				"parentName": "jump_info",
				"enumProperty": {
					"enumeration": [{
						"value": "PAGE_TYPE_H5",
						"description": "自定义落地页"
					}, {
						"value": "PAGE_TYPE_XJ_WEB_H5",
						"description": "蹊径网页落地页"
					}, {
						"value": "PAGE_TYPE_WECHAT_MINI_PROGRAM",
						"description": "微信小程序"
					}, {
						"value": "PAGE_TYPE_WECHAT_CANVAS",
						"description": "原生推广页"
					}, {
						"value": "PAGE_TYPE_XJ_QUICK",
						"description": "蹊径性能版落地页"
					}]
				},
				"path": "/text_link/jump_info/page_type"
			},
			"page_spec": {
				"name": "page_spec",
				"elementType": "STRUCT",
				"fieldType": "STRUCT",
				"required": false,
				"description": "落地页数据(详见接口文档)",
				"parentName": "jump_info",
				"path": "/text_link/jump_info/page_spec"
			}
		}
	},
	"floating_zone": {
		"name": "floating_zone",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": false,
		"description": "浮层卡片组件",
		"parentName": "",
		"enumProperty": {
			"default": ""
		},
		"arrayProperty": {
			"minNumber": 0,
			"maxNumber": 1
		},
		"structProperty": {},
		"restriction": {},
		"children": {
			"floating_zone_switch": {
				"name": "floating_zone_switch",
				"elementType": "BOOLEAN",
				"fieldType": "BOOLEAN",
				"required": true,
				"description": "浮层卡片开关",
				"parentName": "floating_zone",
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {}
			},
			"floating_zone_image_id": {
				"name": "floating_zone_image_id",
				"elementType": "IMAGE",
				"fieldType": "STRING",
				"required": false,
				"description": "创意图片",
				"parentName": "floating_zone",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"imageRestriction": {
						"width": 800,
						"height": 800,
						"fileSize": 400,
						"fileFormat": ["IMAGE_TYPE_JPG", "IMAGE_TYPE_PNG"]
					}
				}
			},
			"floating_zone_name": {
				"name": "floating_zone_name",
				"elementType": "TEXT",
				"fieldType": "STRING",
				"required": false,
				"description": "文案一",
				"parentName": "floating_zone",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"textRestriction": {
						"minLength": 1,
						"maxLength": 10,
						"textPattern": "^[^\\<\\>\\&'\\\"\\x08\\x09\\x0A\\x0D\\\\]+$"
					}
				}
			},
			"floating_zone_desc": {
				"name": "floating_zone_desc",
				"elementType": "TEXT",
				"fieldType": "STRING",
				"required": false,
				"description": "文案二",
				"parentName": "floating_zone",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"textRestriction": {
						"minLength": 1,
						"maxLength": 14,
						"textPattern": "^[^\\<\\>\\&'\\\"\\x08\\x09\\x0A\\x0D\\\\]+$"
					}
				}
			},
			"floating_zone_button_text": {
				"name": "floating_zone_button_text",
				"elementType": "TEXT",
				"fieldType": "STRING",
				"required": false,
				"description": "按钮文字，当前仅支持“了解更多”,“去逛逛”,“查看详情”,“立即体验”,“立即咨询”,“立即开通”,“立即抢购”,“立即申请”,“立即秒杀”,“立即购买”,“立即预定”,“立即预约”,“立即领取”,“观看直播”,“进入小程序”,“领取优惠”",
				"parentName": "floating_zone",
				"enumProperty": {
					"enumeration": [{
						"value": "了解更多",
						"description": "",
						"category": ""
					}, {
						"value": "去逛逛",
						"description": "",
						"category": ""
					}, {
						"value": "查看详情",
						"description": "",
						"category": ""
					}, {
						"value": "立即体验",
						"description": "",
						"category": ""
					}, {
						"value": "立即咨询",
						"description": "",
						"category": ""
					}, {
						"value": "立即开通",
						"description": "",
						"category": ""
					}, {
						"value": "立即抢购",
						"description": "",
						"category": ""
					}, {
						"value": "立即申请",
						"description": "",
						"category": ""
					}, {
						"value": "立即秒杀",
						"description": "",
						"category": ""
					}, {
						"value": "立即购买",
						"description": "",
						"category": ""
					}, {
						"value": "立即预定",
						"description": "",
						"category": ""
					}, {
						"value": "立即预约",
						"description": "",
						"category": ""
					}, {
						"value": "立即领取",
						"description": "",
						"category": ""
					}, {
						"value": "观看直播",
						"description": "",
						"category": ""
					}, {
						"value": "进入小程序",
						"description": "",
						"category": ""
					}, {
						"value": "领取优惠",
						"description": "",
						"category": ""
					}],
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"textRestriction": {
						"minLength": 1,
						"maxLength": 10,
						"textPattern": "^[^\\<\\>\\&'\\\"\\x08\\x09\\x0A\\x0D\\\\]+$"
					}
				}
			},
			"floating_zone_type": {
				"name": "floating_zone_type",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": false,
				"description": "浮层卡片类型",
				"parentName": "floating_zone",
				"enumProperty": {
					"enumeration": [{
						"value": "FLOATING_ZONE_TYPE_IMAGE_TEXT",
						"description": "图文复合类型"
					}, {
						"value": "FLOATING_ZONE_TYPE_SINGLE_IMAGE",
						"description": "单图类型"
					}, {
						"value": "FLOATING_ZONE_TYPE_MULTI_BUTTON",
						"description": "多按钮类型"
					}, {
						"value": "FLOATING_ZONE_TYPE_SLIDER_CARD",
						"description": "轮播卡片类型"
					}],
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {}
			},
			"floating_zone_single_image_id": {
				"name": "floating_zone_single_image_id",
				"elementType": "IMAGE",
				"fieldType": "STRING",
				"required": false,
				"description": "创意图片单图",
				"parentName": "floating_zone",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"imageRestriction": {
						"width": 540,
						"height": 276,
						"fileSize": 2048,
						"fileFormat": ["IMAGE_TYPE_JPG", "IMAGE_TYPE_PNG"]
					}
				}
			}
		}
	},
	"count_down": {
		"name": "count_down",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": false,
		"description": "倒计时组件",
		"enumProperty": {},
		"arrayProperty": {
			"minNumber": 0,
			"maxNumber": 1
		},
		"structProperty": {},
		"restriction": {},
		"children": {
			"switch": {
				"name": "switch",
				"elementType": "BOOLEAN",
				"fieldType": "BOOLEAN",
				"required": true,
				"description": "倒计时开关",
				"parentName": "count_down",
				"enumProperty": {},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {}
			},
			"expiring_timestamp": {
				"name": "expiring_timestamp",
				"elementType": "TEXT",
				"fieldType": "INTEGER",
				"required": false,
				"description": "左下倒计时(选填)",
				"parentName": "count_down",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"textRestriction": {
						"minLength": 1,
						"maxLength": 10,
						"textPattern": "^[^\\<\\>\\&'\\\"\\x08\\x09\\x0A\\x0D\\\\]+$"
					}
				}
			},
			"time_type": {
				"name": "time_type",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": false,
				"description": "倒计时时间描述",
				"parentName": "count_down",
				"enumProperty": {
					"enumeration": [{
						"value": "COUNTDOWN_TIME_START",
						"description": "距离活动开始"
					}, {
						"value": "COUNTDOWN_TIME_END",
						"description": "距离活动结束"
					}]
				},
				"arrayProperty": {},
				"structProperty": {}
			}
		}
	},
	"show_data": {
		"name": "show_data",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": false,
		"description": "数据外显组件",
		"enumProperty": {},
		"arrayProperty": {
			"minNumber": 0,
			"maxNumber": 1
		},
		"structProperty": {},
		"restriction": {},
		"children": {
			"conversion_data_type": {
				"name": "conversion_data_type",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": false,
				"description": "转化数据类型",
				"parentName": "show_data",
				"enumProperty": {
					"enumeration": [{
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "GET_COUPONS"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "GET_COUPONS"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "MAKE_AN_APPOINTMENT"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "MAKE_AN_APPOINTMENT"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "RESERVATION_BUY"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "RESERVATION_BUY"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "BUY_NOW"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "BUY_NOW"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "APPLY_NOW"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "APPLY_NOW"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "RESERVE_NOW"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "RESERVE_NOW"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "CONSULT_NOW"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "CONSULT_NOW"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": "BOOK_DRIVE"
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": "BOOK_DRIVE"
					}, {
						"value": "CONVERSION_DATA_DEFAULT",
						"description": "不使用",
						"category": "WATCH_LIVE"
					}, {
						"value": "CONVERSION_DATA_ADMETRIC",
						"description": "转化数据量",
						"category": ""
					}, {
						"value": "CONVERSION_DATA_PRODUCT_DATA",
						"description": "商品数据",
						"category": ""
					}],
					"default": ""
				}
			},
			"conversion_target_type": {
				"name": "conversion_target_type",
				"elementType": "ENUM",
				"fieldType": "ENUM",
				"required": false,
				"description": "转化数据量类型",
				"parentName": "show_data",
				"enumProperty": {
					"enumeration": [{
						"value": "CONVERSION_TARGET_GET",
						"description": "领取",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_TARGET_RESERVE",
						"description": "预约",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_TARGET_BUY",
						"description": "购买",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_TARGET_APPLY",
						"description": "申请",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_TARGET_CONSULT",
						"description": "咨询",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_TARGET_ADD_WECOM",
						"description": "加企微",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "GO_SHOPPING"
					}, {
						"value": "CONVERSION_TARGET_GET",
						"description": "领取",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_RESERVE",
						"description": "预约",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_BUY",
						"description": "购买",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_APPLY",
						"description": "申请",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_CONSULT",
						"description": "咨询",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_ADD_WECOM",
						"description": "加企微",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_DONATION",
						"description": "捐款",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_GOOD_DEED",
						"description": "做好事",
						"category": "MORE_INFO"
					}, {
						"value": "CONVERSION_TARGET_GET",
						"description": "领取",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_TARGET_RESERVE",
						"description": "预约",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_TARGET_BUY",
						"description": "购买",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_TARGET_APPLY",
						"description": "申请",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_TARGET_CONSULT",
						"description": "咨询",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_TARGET_ADD_WECOM",
						"description": "加企微",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "ENTER_MINI_PROGRAM"
					}, {
						"value": "CONVERSION_TARGET_GET",
						"description": "领取",
						"category": "GET_COUPONS"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "GET_COUPONS"
					}, {
						"value": "CONVERSION_TARGET_RESERVE",
						"description": "预约",
						"category": "MAKE_AN_APPOINTMENT"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "MAKE_AN_APPOINTMENT"
					}, {
						"value": "CONVERSION_TARGET_RESERVE",
						"description": "预约",
						"category": "RESERVATION_BUY"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "RESERVATION_BUY"
					}, {
						"value": "CONVERSION_TARGET_BUY",
						"description": "购买",
						"category": "BUY_NOW"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "BUY_NOW"
					}, {
						"value": "CONVERSION_TARGET_APPLY",
						"description": "申请",
						"category": "APPLY_NOW"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "APPLY_NOW"
					}, {
						"value": "CONVERSION_TARGET_RESERVE",
						"description": "预约",
						"category": "RESERVE_NOW"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "RESERVE_NOW"
					}, {
						"value": "CONVERSION_TARGET_CONSULT",
						"description": "咨询",
						"category": "CONSULT_NOW"
					}, {
						"value": "CONVERSION_TARGET_ADD_WECOM",
						"description": "加企微",
						"category": "CONSULT_NOW"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "CONSULT_NOW"
					}, {
						"value": "CONVERSION_TARGET_RESERVE",
						"description": "预约",
						"category": "BOOK_DRIVE"
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": "BOOK_DRIVE"
					}, {
						"value": "CONVERSION_TARGET_GET",
						"description": "领取",
						"category": ""
					}, {
						"value": "CONVERSION_TARGET_RESERVE",
						"description": "预约",
						"category": ""
					}, {
						"value": "CONVERSION_TARGET_BUY",
						"description": "购买",
						"category": ""
					}, {
						"value": "CONVERSION_TARGET_APPLY",
						"description": "申请",
						"category": ""
					}, {
						"value": "CONVERSION_TARGET_CONSULT",
						"description": "咨询",
						"category": ""
					}, {
						"value": "CONVERSION_TARGET_LIKE",
						"description": "想看",
						"category": ""
					}, {
						"value": "CONVERSION_TARGET_DONATION",
						"description": "捐款",
						"category": ""
					}, {
						"value": "CONVERSION_TARGET_GOOD_DEED",
						"description": "做好事",
						"category": ""
					}],
					"default": ""
				}
			}
		}
	},
	"label": {
		"name": "label",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": false,
		"description": "标签",
		"parentName": "",
		"enumProperty": {
			"default": ""
		},
		"arrayProperty": {
			"minNumber": 0,
			"maxNumber": 1
		},
		"structProperty": {},
		"restriction": {},
		"children": {
			"list": {
				"name": "list",
				"elementType": "STRUCT",
				"fieldType": "STRUCT_ARRAY",
				"required": true,
				"description": "标签",
				"parentName": "label",
				"enumProperty": {},
				"arrayProperty": {
					"minNumber": 1,
					"maxNumber": 3
				},
				"structProperty": {},
				"restriction": {},
				"children": {
					"content": {
						"name": "content",
						"elementType": "TEXT",
						"fieldType": "STRING",
						"required": true,
						"description": "标签内容",
						"parentName": "list",
						"restriction": {
							"textRestriction": {
								"minLength": 2,
								"maxLength": 15
							}
						}
					},
					"type": {
						"name": "type",
						"elementType": "ENUM",
						"fieldType": "ENUM",
						"required": false,
						"description": "标签类型",
						"parentName": "list",
						"enumProperty": {
							"enumeration": [{
								"value": "LABEL_TYPE_UNKNOWN",
								"description": "普通标签"
							}, {
								"value": "LABEL_TYPE_PROMOTIONAL",
								"description": "节点营销标签"
							}, {
								"value": "LABEL_TYPE_CUSTOMIZETEXT",
								"description": "自定义标签"
							}, {
								"value": "LABEL_TYPE_ICON",
								"description": "角标"
							}, {
								"value": "LABEL_TYPE_DYNAMIC",
								"description": "动态标签"
							}],
							"default": ""
						},
						"arrayProperty": {},
						"structProperty": {},
						"restriction": {}
					}
				}
			}
		}
	},
	"end_page": {
		"name": "end_page",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": false,
		"description": "视频结束页",
		"parentName": "",
		"enumProperty": {
			"default": ""
		},
		"arrayProperty": {
			"minNumber": 0,
			"maxNumber": 1
		},
		"structProperty": {},
		"restriction": {},
		"children": {
			"end_page_desc": {
				"name": "end_page_desc",
				"elementType": "TEXT",
				"fieldType": "STRING",
				"required": true,
				"description": "结束页文案",
				"parentName": "end_page",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"textRestriction": {
						"minLength": 1,
						"maxLength": 12,
						"textPattern": "^[^\\<\\>\\&'\\\"\\x08\\x09\\x0A\\x0D\\\\]+$"
					}
				}
			},
			"end_page_type": {
				"name": "end_page_type",
				"elementType": "ENUM",
				"fieldType": "STRING",
				"required": true,
				"description": "视频结束页类型",
				"parentName": "end_page",
				"enumProperty": {
					"enumeration": [{
						"value": "END_PAGE_DESCRIPTION_HIGHLIGHT",
						"description": "突出文案",
						"category": ""
					}, {
						"value": "END_PAGE_AVATAR_NICKNAME_HIGHLIGHT",
						"description": "突出头像及昵称",
						"category": ""
					}],
					"default": "END_PAGE_AVATAR_NICKNAME_HIGHLIGHT"
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {}
			}
		}
	}
}

// 视频规则
export const videoRules = {
	"videoL": { // 横板视频 16：9
		"name": "video",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "视频组件",
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 1
		},
		"children": {
			"video_id": {
				"name": "video_id",
				"elementType": "VIDEO",
				"fieldType": "INTEGER",
				"required": true,
				"description": "视频",
				"parentName": "video",
				"restriction": {
					"videoRestriction": {
						"minWidth": 1280,
						"minHeight": 720,
						"ratioWidth": 16,
						"ratioHeight": 9,
						"fileSize": 512000,
						"fileFormat": ["MEDIA_TYPE_MP4", "MEDIA_TYPE_MOV", "MEDIA_TYPE_AVI"],
						"minDuration": 5,
						"maxDuration": 300
					}
				}
			},
			"cover_id": {
				"name": "cover_id",
				"elementType": "IMAGE",
				"fieldType": "STRING",
				"required": true,
				"description": "图片",
				"parentName": "video",
				"restriction": {
					"imageRestriction": {
						"width": 1280,
						"height": 720,
						"fileSize": 400,
						"fileFormat": ["IMAGE_TYPE_JPG", "IMAGE_TYPE_PNG"]
					}
				}
			}
		}
	},
	"videoP": {  // 竖版视频9：16
		"name": "video",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "视频组件",
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 1
		},
		"children": {
			"video_id": {
				"name": "video_id",
				"elementType": "VIDEO",
				"fieldType": "INTEGER",
				"required": true,
				"description": "视频",
				"parentName": "video",
				"restriction": {
					"videoRestriction": {
						"minWidth": 720,
						"minHeight": 1280,
						"ratioWidth": 9,
						"ratioHeight": 16,
						"fileSize": 512000,
						"fileFormat": ["MEDIA_TYPE_MP4", "MEDIA_TYPE_MOV", "MEDIA_TYPE_AVI"],
						"minDuration": 5,
						"maxDuration": 300
					}
				}
			},
			"cover_id": {
				"name": "cover_id",
				"elementType": "IMAGE",
				"fieldType": "STRING",
				"required": true,
				"description": "图片",
				"parentName": "video",
				"restriction": {
					"imageRestriction": {
						"width": 720,
						"height": 1280,
						"fileSize": 400,
						"fileFormat": ["IMAGE_TYPE_JPG", "IMAGE_TYPE_PNG"]
					}
				}
			}
		}
	},
	"short_video": {  // 4：3
		"name": "short_video",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "短视频组件",
		"parentName": "",
		"enumProperty": {
			"default": ""
		},
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 1
		},
		"structProperty": {},
		"restriction": {},
		"children": {
			"cover_id": {
				"name": "cover_id",
				"elementType": "IMAGE",
				"fieldType": "STRING",
				"required": false,
				"description": "视频封面图",
				"parentName": "short_video",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"imageRestriction": {
						"width": 1280,
						"height": 960,
						"fileSize": 300,
						"fileFormat": ["IMAGE_TYPE_JPG", "IMAGE_TYPE_PNG"]
					}
				}
			},
			"short_video1": {
				"name": "short_video1",
				"elementType": "VIDEO",
				"fieldType": "INTEGER",
				"required": true,
				"description": "视频",
				"parentName": "short_video",
				"enumProperty": {
					"default": ""
				},
				"arrayProperty": {},
				"structProperty": {},
				"restriction": {
					"videoRestriction": {
						"minWidth": 640,
						"minHeight": 480,
						"ratioWidth": 4,
						"ratioHeight": 3,
						"fileSize": 512000,
						"fileFormat": ["MEDIA_TYPE_MP4", "MEDIA_TYPE_MOV", "MEDIA_TYPE_AVI"],
						"minDuration": 5,
						"maxDuration": 300
					}
				}
			}
		}
	}
}

export const imageRules = {
	"imageL": { // 横板大图16：9
		"name": "image",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "图片组件",
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 1
		},
		"children": {
			"image_id": {
				"name": "image_id",
				"elementType": "IMAGE",
				"fieldType": "STRING",
				"required": true,
				"description": "图片",
				"parentName": "image",
				"restriction": {
					"imageRestriction": {
						"width": 1280,
						"height": 720,
						"fileSize": 400,
						"fileFormat": ["IMAGE_TYPE_JPG", "IMAGE_TYPE_PNG"]
					}
				}
			}
		}
	},
	"imageP": { // 竖版大图9：16
		"name": "image",
		"elementType": "STRUCT",
		"fieldType": "STRUCT_ARRAY",
		"required": true,
		"description": "图片组件",
		"arrayProperty": {
			"minNumber": 1,
			"maxNumber": 1
		},
		"children": {
			"image_id": {
				"name": "image_id",
				"elementType": "IMAGE",
				"fieldType": "STRING",
				"required": true,
				"description": "图片",
				"parentName": "image",
				"restriction": {
					"imageRestriction": {
						"width": 1080,
						"height": 1920,
						"fileSize": 400,
						"fileFormat": ["IMAGE_TYPE_JPG", "IMAGE_TYPE_PNG"]
					}
				}
			}
		}
	},
}

type AdRules = {
	[goal: string]: {
		[subGoal: string]: any; // 根据实际需要可以更改 any 类型  
	};
};
/** 广告配置数据 */
export const adRules: AdRules = {
	"MARKETING_GOAL_BRAND_PROMOTION": {
		"MARKETING_TARGET_TYPE_APP_ANDROID": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_IOS": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_QUICK_APP": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_MINI_PROGRAM_WECHAT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_WORK": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		}
	},
	"MARKETING_GOAL_INCREASE_FANS_INTERACTION": {
		"MARKETING_TARGET_TYPE_FICTION": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				},
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_MINI_PROGRAM_WECHAT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_SHORT_DRAMA": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				},
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_CHANNELS": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS": {
					"PRODUCT_TYPE": 51,
					"LIVE_MODE": 1
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_CHANNELS_LIVE_RESERVATION": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS_LIVE_RESERVATION": {
					"PRODUCT_TYPE": 51,
					"LIVE_MODE": 2,
					"LIVE_SUB_MODE": 2
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_WORK": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		}
	},
	"MARKETING_GOAL_LEAD_RETENTION": {
		"MARKETING_TARGET_TYPE_ACTIVITY": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_QUICK_APP": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_FICTION": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				},
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_MINI_PROGRAM_WECHAT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_SHORT_DRAMA": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				},
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_CHANNELS": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS": {
					"PRODUCT_TYPE": 51,
					"LIVE_MODE": 1
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_CHANNELS_LIVE_RESERVATION": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS_LIVE_RESERVATION": {
					"PRODUCT_TYPE": 51,
					"LIVE_MODE": 2,
					"LIVE_SUB_MODE": 2
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_WORK": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		}
	},
	"MARKETING_GOAL_PRODUCT_SALES": {
		"MARKETING_TARGET_TYPE_ACTIVITY": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				},
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_ANDROID": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_IOS": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_QUICK_APP": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_FICTION": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				},
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				},
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				},
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_MINI_PROGRAM_WECHAT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_PLATFORM_CHANNEL": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				},
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				}
			}
		},
		"MARKETING_TARGET_TYPE_SHORT_DRAMA": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				},
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				},
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_CHANNELS": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS": {
					"PRODUCT_TYPE": 51,
					"LIVE_MODE": 1
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_CHANNELS_LIVE_RESERVATION": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS_LIVE_RESERVATION": {
					"PRODUCT_TYPE": 51,
					"LIVE_MODE": 2,
					"LIVE_SUB_MODE": 2
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_WORK": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		}
	},
	"MARKETING_GOAL_USER_GROWTH": {
		"MARKETING_TARGET_TYPE_ACTIVITY": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				},
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_ANDROID": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_IOS": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				}
			}
		},
		"MARKETING_TARGET_TYPE_APP_QUICK_APP": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_FICTION": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				},
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				},
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				},
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_MINI_PROGRAM_WECHAT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_TARGET_TYPE_PLATFORM_CHANNEL": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				},
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				}
			}
		},
		"MARKETING_TARGET_TYPE_SHORT_DRAMA": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_APP_ANDROID": {
					"PRODUCT_TYPE": 12
				},
				"MARKETING_CARRIER_TYPE_APP_IOS": {
					"PRODUCT_TYPE": 19
				},
				"MARKETING_CARRIER_TYPE_APP_QUICK_APP": {
					"PRODUCT_TYPE": 53
				},
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				},
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_CHANNELS": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS": {
					"PRODUCT_TYPE": 51,
					"LIVE_MODE": 1
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_CHANNELS_LIVE_RESERVATION": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS_LIVE_RESERVATION": {
					"PRODUCT_TYPE": 51,
					"LIVE_MODE": 2,
					"LIVE_SUB_MODE": 2
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				},
				"MARKETING_CARRIER_TYPE_WECHAT_OFFICIAL_ACCOUNT": {
					"PRODUCT_TYPE": 23
				}
			}
		},
		"MARKETING_TARGET_TYPE_WECHAT_WORK": {
			"MARKETING_SUB_GOAL_UNKNOWN": {
				"MARKETING_CARRIER_TYPE_JUMP_PAGE": {
					"PRODUCT_TYPE": 43
				}
			}
		},
		"MARKETING_SUB_GOAL_MINI_GAME_NEW_CUSTOMER_GROWTH": {
			"MARKETING_TARGET_TYPE_WECHAT_MINI_GAME": {
				"MARKETING_SUB_GOAL_UNKNOWN": {
					"MARKETING_CARRIER_TYPE_WECHAT_MINI_GAME": {},
					"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS_LIVE": {}
				}
			}
		},
		"MARKETING_SUB_GOAL_NEW_GAME_TEST": {
			"MARKETING_TARGET_TYPE_WECHAT_MINI_GAME": {
				"MARKETING_SUB_GOAL_UNKNOWN": {
					"MARKETING_CARRIER_TYPE_WECHAT_MINI_GAME": {},
					"MARKETING_CARRIER_TYPE_WECHAT_CHANNELS_LIVE": {}
				}
			}
		}
	}
}